@@ -16,13 +16,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 ##
-from datetime import date, datetime
+from datetime import datetime
 from aceql._private.aceql_http_api import AceQLHttpApi
+from aceql._private.connection_util import ConnectionUtil
 from aceql.cursor import Cursor
 from aceql.connection_options import ConnectionOptions
 from aceql.progress_indicator import ProgressIndicator
 from aceql.login_url_decoder import LoginUrlDecoder
 
+from aceql._private.dto.database_info_dto import DatabaseInfoDto
+from aceql.database_info import DatabaseInfo
+
+
 class Connection(object):
     """Allows to create a database connection to a remote server."""
 
@@ -159,6 +164,17 @@ class Connection(object):
         """Gets the server version of AceQL HTTP."""
         return self.__aceQLHttpApi.get_server_version()
 
+    def get_database_info(self) -> DatabaseInfo:
+        """Get the the remote database and remote JDBC Driver basic info"""
+
+        if not ConnectionUtil.is_get_database_info_supported(self):
+            raise Exception("AceQL Server version must be >= " + ConnectionUtil.GET_DATABASE_INFO_MIN_SERVER_VERSION
+                + " in order to call get_database_info.")
+
+        database_info_dto: DatabaseInfoDto = self.__aceQLHttpApi.get_database_info()
+        databaseInfo: DatabaseInfo = DatabaseInfo(database_info_dto)
+        return databaseInfo
+
     def close(self):
         """Closes the connection to the remote database but keeps the HTTP session."""
         self.__aceQLHttpApi.close()
